@@ -246,7 +246,7 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
         fields_ = []
         for field in fields:
             if not field in fields_:
-                title = '_'.join(field.split('-')[-1].split('_')[1:]).capitalize()
+                title = '_'.join(field.split('-')[-1].split('_')[1:])
                 object_name = field[:field.find('_')]
                 if object_name == self.getId():
                     object = None
